@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import cmath
+from dataclasses import dataclass
 from typing import Any, Optional, SupportsIndex
 
 
@@ -49,50 +50,65 @@ def _object_to_xy(obj: Any, /) -> tuple:
         )
 
 
-class Vector(complex):
+@dataclass(frozen=True, init=False, repr=False)
+class Vector:
     """A two-dimensional vector."""
 
-    def __new__(
-        cls,
-        /,
-        x: Optional[float] = None,
+    _complex: complex
+
+    def __init__(
+        self,
+        x: Any = None,
         y: Optional[float] = None,
         *,
         r: Optional[float] = None,
         theta: Optional[float] = None,
         angle_unit: str = "rad",
     ):
-        if x is None:
-            if y is not None:
-                raise ValueError("Must give x to create Vector if y is given")
-            # Create Vector from polar arguments
-            if r == 0:
-                return super().__new__(cls, 0)
-            if r is None or theta is None:
-                raise ValueError("Insufficient information to create Vector")
-            return super().__new__(cls, cmath.rect(r, convert_angle(theta, angle_unit)))
-        if r is not None or theta is not None:
+        if r is None and theta is None:
+            if y is None:
+                if isinstance(x, complex):
+                    object.__setattr__(self, "_complex", x)
+                else:
+                    # Create Vector from a single argument using the
+                    # implementation _complex provides
+                    try:
+                        object.__setattr__(self, "_complex", complex(x))
+                    except TypeError:
+                        # Get x and y values using our implementation
+                        object.__setattr__(self, "_complex", complex(*_object_to_xy(x)))
+            else:
+                if x is None:
+                    raise ValueError("Must give x to create Vector if y is given")
+                # Create Vector from x and y
+                try:
+                    object.__setattr__(self, "_complex", complex(x, y))
+                except TypeError:
+                    raise TypeError("x and y values must be numeric to create Vector")
+            return
+
+        if x is not None or y is not None:
             raise ValueError(
                 "Cannot create Vector from mixed rectangular and polar arguments"
             )
-        if y is None:
-            # Create Vector from a single argument using the
-            # implementation complex provides
-            try:
-                return super().__new__(cls, x)
-            except TypeError:
-                # Get x and y values using our implementation
-                x, y = _object_to_xy(x)
 
-        # Create Vector from x and y
-        try:
-            return super().__new__(cls, x, y)
-        except TypeError:
-            raise TypeError("x and y values must be numeric to create Vector")
+        # Create Vector from polar arguments
+        if r == 0:
+            return Vector(0)
+        if r is None or theta is None:
+            raise ValueError(
+                "must provide both r and theta to create Vector from polar"
+            )
+        object.__setattr__(
+            self, "_complex", cmath.rect(r, convert_angle(theta, angle_unit))
+        )
 
     def dot(self, other: Vector, /) -> float:
         """Return the dot product of self and other."""
-        return self.real * other.real + self.imag * other.imag
+        return (
+            self._complex.real * other._complex.real
+            + self._complex.imag * other._complex.imag
+        )
 
     def perp_dot(self, other: Vector, /) -> float:
         """
@@ -102,7 +118,10 @@ class Vector(complex):
         also one of the 'cross products' that can be defined on 2D
         vectors.
         """
-        return self.real * other.imag - self.imag * other.real
+        return (
+            self._complex.real * other._complex.imag
+            - self._complex.imag * other._complex.real
+        )
 
     def perp(self, /) -> Vector:
         """
@@ -111,7 +130,7 @@ class Vector(complex):
         This is one of the 'cross products' that can be defined on 2D
         vectors. Use -Vector.perp() for a clockwise rotation.
         """
-        return Vector(-self.imag, self.real)
+        return Vector(complex(-self._complex.imag, self._complex.real))
 
     def rotate(self, angle: float, /, unit="rad") -> Vector:
         """
@@ -120,7 +139,7 @@ class Vector(complex):
         Use negative angles for a clockwise rotation.
         """
         angle = convert_angle(angle, unit)
-        return Vector(r=self.r, theta=self.theta + angle)
+        return Vector(cmath.rect(self.r, self.theta + angle))
 
     def hat(self, /) -> Vector:
         """Return a Vector with the same direction, but unit length."""
@@ -128,20 +147,22 @@ class Vector(complex):
 
     def rec(self, /) -> tuple[float, float]:
         """Get the vector as (x, y)."""
-        return (self.real, self.imag)
+        return (self._complex.real, self._complex.imag)
 
     def pol(self, /) -> tuple[float, float]:
         """Get the vector as (r, theta)."""
-        return cmath.polar(self)
+        return cmath.polar(self._complex)
 
     def round(self, ndigits: int = 0, /) -> tuple:
-        return (round(self.real, ndigits), round(self.imag, ndigits))
-
-    def __repr__(self, /):
-        return f"{self.__class__.__qualname__}({self.real}, {self.imag})"
+        return (round(self._complex.real, ndigits), round(self._complex.imag, ndigits))
 
     def __str__(self, /):
-        return f"({self.real} {self.imag})"
+        return f"({self._complex.real} {self._complex.imag})"
+
+    def __repr__(self, /):
+        return (
+            f"{self.__class__.__qualname__}({self._complex.real}, {self._complex.imag})"
+        )
 
     def __len__(self, /):
         return 2
@@ -150,46 +171,45 @@ class Vector(complex):
         return self.rec()[key]
 
     def __contains__(self, item: float, /):
-        return item == self.real or item == self.imag
+        return item == self._complex.real or item == self._complex.imag
 
     def __iter__(self, /):
-        yield self.real
-        yield self.imag
+        yield self._complex.real
+        yield self._complex.imag
 
     def __reversed__(self, /):
-        yield self.imag
-        yield self.real
+        yield self._complex.imag
+        yield self._complex.real
+
+    def __neg__(self, /):
+        return Vector(-self._complex)
 
     def __add__(self, other: Vector, /) -> Vector:
-        return Vector(self.real + other.real, self.imag + other.imag)
+        return Vector(self._complex + other._complex)
 
     def __sub__(self, other: Vector, /) -> Vector:
-        return Vector(self.real - other.real, self.imag - other.imag)
+        return Vector(self._complex - other._complex)
 
-    def __mul__(self, other: Vector, /) -> Vector:
-        return Vector(super().__mul__(other))
+    def __mul__(self, value: float, /) -> Vector:
+        return Vector(self._complex * value)
 
-    def __truediv__(self, other: Vector, /) -> Vector:
-        return Vector(super().__truediv__(other))
+    def __truediv__(self, value: float, /) -> Vector:
+        return Vector(self._complex / value)
 
-    def __pow__(self, value: float, mod=None, /) -> Vector:
-        return Vector(super().__pow__(value, mod))
-
-    __radd__ = __add__
-    __rsub__ = __sub__
     __rmul__ = __mul__
-    __rtruediv__ = __truediv__
-    __rpow__ = __pow__
+
+    def __abs__(self) -> float:
+        return abs(self._complex)
 
     @property
     def x(self) -> float:
         """The horizontal component of the vector."""
-        return self.real
+        return self._complex.real
 
     @property
     def y(self) -> float:
         """The vertical component of the vector."""
-        return self.imag
+        return self._complex.imag
 
     @property
     def r(self) -> float:
@@ -204,4 +224,4 @@ class Vector(complex):
         Negative values are clockwise. Returns values in the range
         [-pi, pi]. See documentation of cmath.phase for details.
         """
-        return cmath.phase(self)
+        return cmath.phase(self._complex)
